function [pID,npID,pH,npH,pN,npN] = getFDR(p,q)
  % This function get the FDR corrected p-value threshold
  %   FORMAT pt = FDR(p,q)
  %
  % p   - vector of p-values
  % q   - False Discovery Rate level
  %
  % pID - p-value threshold based on independence or positive dependence
  % pN  - Nonparametric p-value threshold
  % pH  -Hochberg 1988
  %______________________________________________________________________________
  % @(#)FDR.m     1.3 Tom Nichols 02/01/18
 
 
  p = sort(p(:));
  V = length(p);
  I = (1:V)';
  %I = (1:length(p))';
 
  cVID = 1;
  cVN = sum(1./(1:V));
  %cVN = sum(1./(1:length(p)));
  npID=max(find(p<=I/V*q/cVID));
  pID = p(npID);
  npH=max(find(p<=1./(V-I+1)*q/cVID));
  pH=p(npH);
  npN=max(find(p<=I/V*q/cVN));
  pN = p(npN);
 
  if isempty(pID)
    pID = NaN;
    npID=0;
  end
    if isempty(pH)
    pH = NaN;
    npH=0;
  end
  if isempty(pN)
    pN = NaN;
    npN=0;
  end
  
  
  